#include "stdafx.h"
#include "resource.h"

//   
void DrawBoard (HDC hdc, const RECT& rc)
{
	//  
	HBRUSH board = CreateSolidBrush (RGB (240,240,240));	//   
	HBRUSH white = CreateSolidBrush (RGB (255,255,192));	//   
	HBRUSH black = CreateSolidBrush (RGB (0,0,80));			//   

	//     , 
	//       
	int width = rc.right - rc.left + 1;
	int height = rc.bottom - rc.top + 1;
	int sx = 0;							//   
	int sy = 0;							//  
	if (width > height) {
		sx = (width - height) / 2;
		width = height;
	} else {
		sy = (height - width) / 2;
		height = width;
	}
	int cell_width = width / 10;		//   
	int cell_height = height / 10;		//   

	//   
	HBRUSH old_brush = (HBRUSH) SelectObject (hdc, board);
	Rectangle (hdc, sx + 1, sy + 1, sx + width - 2, sy + height - 2);

	//    
	for (int i = 0; i < 8; ++i) {
		for (int j = 0; j < 8; ++j) {

			//   
			SelectObject (hdc, ((i ^ j) & 1) ? black : white);

			//   
			int x = sx + (i + 1) * cell_width;
			int y = sy + (j + 1) * cell_height;
			Rectangle (hdc, x, y, x + cell_width, y + cell_height);
		}
	}

	//     
	SetBkMode (hdc, TRANSPARENT);

	//     
	RECT rcLetter;
	char letter;
	for (i = 0; i < 8; ++i) {
		//  A-H
		letter = i + 'A';
		rcLetter.left = sx + (i + 1) * cell_width;
		rcLetter.right = rcLetter.left + cell_width;
		rcLetter.top = sy;
		rcLetter.bottom = rcLetter.top + cell_height;
		DrawText (hdc, &letter, 1, &rcLetter, DT_CENTER | DT_VCENTER | DT_SINGLELINE);
		rcLetter.top = sy + 9 * cell_height;
		rcLetter.bottom = rcLetter.top + cell_height;		
		DrawText (hdc, &letter, 1, &rcLetter, DT_CENTER | DT_VCENTER | DT_SINGLELINE);
		
		//  1-8
		letter = i + '1';
		rcLetter.left = sx;
		rcLetter.right = rcLetter.left + cell_width;
		rcLetter.top = sy + (8 - i) * cell_height;
		rcLetter.bottom = rcLetter.top + cell_height;
		DrawText (hdc, &letter, 1, &rcLetter, DT_CENTER | DT_VCENTER | DT_SINGLELINE);
		rcLetter.left = sx + 9 * cell_width;
		rcLetter.right = rcLetter.left + cell_width;
		DrawText (hdc, &letter, 1, &rcLetter, DT_CENTER | DT_VCENTER | DT_SINGLELINE);
	}

	//  
	SelectObject (hdc, old_brush);
    DeleteObject (board);
	DeleteObject (white);
	DeleteObject (black);
}

//     
LRESULT CALLBACK WndProc (HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	switch (message) {
		//  
		case WM_PAINT:
			{
				//  ,    ()
				PAINTSTRUCT ps;
				HDC hdc = BeginPaint (hWnd, &ps);

				//     
				RECT rcClient;
				GetClientRect (hWnd, &rcClient);

				//  
				DrawBoard (hdc, rcClient);

				//  ,  
				EndPaint (hWnd, &ps);
			}
			break;

		//   
		case WM_DESTROY:
			PostQuitMessage (0);
			break;

		//      
		default:
			return DefWindowProc (hWnd, message, wParam, lParam);
	}
	return 0;
}

//   
int APIENTRY _tWinMain (HINSTANCE hInstance, HINSTANCE, LPTSTR lpCmdLine, int nCmdShow)
{
	//   
	WNDCLASSEX wcex;
	ZeroMemory (&wcex, sizeof (wcex));
	wcex.cbSize = sizeof (WNDCLASSEX);
	wcex.style			= CS_HREDRAW | CS_VREDRAW;
	wcex.lpfnWndProc	= (WNDPROC) WndProc;
	wcex.hInstance		= hInstance;
	wcex.hIcon			= LoadIcon (hInstance, (LPCTSTR) IDI_LB041202);	//  
	wcex.hCursor		= LoadCursor (NULL, IDC_ARROW);					//  
	wcex.hbrBackground	= (HBRUSH) (COLOR_APPWORKSPACE + 1);			//   
	wcex.lpszClassName	= "lb041202";
	RegisterClassEx (&wcex);

	//       
	HWND hWnd = CreateWindow (wcex.lpszClassName, wcex.lpszClassName, WS_OVERLAPPEDWINDOW,
      CW_USEDEFAULT, 0, CW_USEDEFAULT, 0, NULL, NULL, hInstance, NULL);
	ShowWindow (hWnd, nCmdShow);
	UpdateWindow (hWnd);

	//     
	MSG msg;
	while (GetMessage(&msg, NULL, 0, 0)) {
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	return (int) msg.wParam;
}
